==> e2guardian_3.4.0.3.orig.tar.gz: e2guardian-3.4.0.3/README.md <==
# [E2Guardian](http://e2guardian.org)

**For all support, instructions and copyright go to: http://e2guardian.org**

e2guardian is a content filtering proxy that works in conjunction with another
caching proxy such as Squid or Oops. More information can be found in the
e2guardian(8) man page, the "doc" subdirectory of the distribution, and the
comments in the configuration and list files themselves.

e2guardian is a fork of [DansGuardian](http://dansguardian.org) and the maintainers fully acknowledge
the work carried out by and the copyright of Daniel Baron and other
contributors to the Dansguardian project.

Read the INSTALL for installation instructions.

## Contributing

Github: https://github.com/e2guardian

*	Develop is used to develop new features
*	Bugfixes primarily occurs in the default branch

## Bugs and Feature Requests

Github: https://github.com/e2guardian/e2guardian/issues

## Community

*	 Join the [Community
    Forum](https://groups.google.com/forum/#!forum/e2guardian).

## License

Copyright 2014, Philip Pearce [E2BN Protex](http://protex.e2bn.org) Ltd, [Frederic Bourgeois](http://numsys.eu) and others.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License version 2 as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

In addition, as a special exception, the copyright holders
of this work, give permission to link the code of its release of e2guardian
with the OpenSSL project's "OpenSSL" library (or with modified versions of
it that use the same license as the "OpenSSL" library), and distribute the
linked executables.  You must obey the GNU General Public License in all
respects for all of the code used other than "OpenSSL".  If you modify this
file, you may extend this exception to your version of the file, but you are
not obligated to do so.  If you do not wish to do so, delete this exception
statement from your version.

==> e2guardian-4.1.2.tar.gz: e2guardian-4.1.2/README.md <==
# [E2Guardian](http://e2guardian.org)

**For all support, instructions and copyright go to: http://e2guardian.org**

e2guardian is a content filtering proxy that works in conjunction with another
caching proxy such as Squid or Oops. More information can be found in the
e2guardian(8) man page, the "doc" subdirectory of the distribution, and the
comments in the configuration and list files themselves.

e2guardian is a fork of [DansGuardian](http://dansguardian.org) and the maintainers fully acknowledge
the work carried out by and the copyright of Daniel Baron and other contributors to the Dansguardian project. 

DansGuardian is licensed under the GPL version 2 with permission to link OpenSSL

Read the INSTALL for installation instructions.

## Contributing

Github: https://github.com/e2guardian

*	Develop is used to develop new features
*	Bugfixes primarily occurs in the default branch

## Bugs and Feature Requests

Github: https://github.com/e2guardian/e2guardian/issues

## Community

*	 Join the [Community
    Forum](https://groups.google.com/forum/#!forum/e2guardian).

## License

Copyright 2014, Philip Pearce [E2BN Protex](http://protex.e2bn.org) Ltd, [Frederic Bourgeois](http://numsys.eu) and others.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License version 2 as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

In addition, as a special exception, the copyright holders
of this work, give permission to link the code of its release of e2guardian
with the OpenSSL project's "OpenSSL" library (or with modified versions of
it that use the same license as the "OpenSSL" library), and distribute the
linked executables.  You must obey the GNU General Public License in all
respects for all of the code used other than "OpenSSL".  If you modify this
file, you may extend this exception to your version of the file, but you are
not obligated to do so.  If you do not wish to do so, delete this exception
statement from your version.
